@@ -60,5 +60,5 @@ CommandType = TypeVar('CommandType', bound='CommandMeta')
 CommandCls = Union[CommandType, Type[CommandObj]]
 CommandAny = Union[CommandCls, CommandObj]
 
-DefaultFunc = Callable[[], T_co]
 CommandMethod = Callable[[CommandObj], T_co]
+DefaultFunc = Union[Callable[[], T_co], CommandMethod]
